summaryrefslogtreecommitdiffstats
path: root/src/privsep-root.c
diff options
context:
space:
mode:
authorRoy Marples <roy@marples.name>2021-02-02 17:09:25 +0000
committerRoy Marples <roy@marples.name>2021-02-02 17:09:25 +0000
commitdef6e99252c1d3c549a37543b1914b0b8a342851 (patch)
tree11bc57efa44a2a4264ecd6a2f0922b6ec8d971f6 /src/privsep-root.c
parentf6082bca98c2d16492d56e98ec9ea927c36c248a (diff)
downloaddhcpcd-def6e99252c1d3c549a37543b1914b0b8a342851.tar.xz
Rename Privileged Actioneer to Privileged Proxy
Sadly actioneer is not a real word.
Diffstat (limited to 'src/privsep-root.c')
-rw-r--r--src/privsep-root.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/privsep-root.c b/src/privsep-root.c
index 92406c4d..c04cf221 100644
--- a/src/privsep-root.c
+++ b/src/privsep-root.c
@@ -1,6 +1,6 @@
/* SPDX-License-Identifier: BSD-2-Clause */
/*
* Privilege Separation for dhcpcd, privileged actioneer
* Copyright (c) 2006-2021 Roy Marples <roy@marples.name>
* All rights reserved
@@ -649,9 +649,9 @@ ps_root_startcb(void *arg)
struct dhcpcd_ctx *ctx = arg;
if (ctx->options & DHCPCD_MANAGER)
- setproctitle("[privileged actioneer]");
+ setproctitle("[privileged proxy]");
else
- setproctitle("[privileged actioneer] %s%s%s",
+ setproctitle("[privileged proxy] %s%s%s",
ctx->ifv[0],
ctx->options & DHCPCD_IPV4 ? " [ip4]" : "",
ctx->options & DHCPCD_IPV6 ? " [ip6]" : "");
@@ -1,6 +1,6 @@
/* SPDX-License-Identifier: BSD-2-Clause */
/*
- * Privilege Separation for dhcpcd, privileged actioneer
+ * Privilege Separation for dhcpcd, privileged proxy
* Copyright (c) 2006-2021 Roy Marples <roy@marples.name>
* All rights reserved